function [output]=  BonHomV1p3 (input,option)

%% modification 8 jan 2015
% BonHomV1p3 is issued of BonHomV1p2. Changes have been made l64-65 (definition of R and phi)
%% 
disp('BonHom programm running....')
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright 2010-, % Quentin Grimal (quentin.grimal@upmc.fr) and William
% Parnell (william.parnell@manchester.ac.uk)
% This program is citation-ware. If you are publishing any work, where this
% program has been used, you must reference the paper
%
% Parnell, W.J. and Grimal, Q.
% 'The influence of mesoscopic porosity on cortical bone anisotropy.
% Investigations via asymptotic homogenization'
% Journal of the Royal Society Interface 6 (2009) 97-109

%%%%%%% Program description
% BoHom function for the evaluation of the transverse isotropic (TI) homogenized properties of a
% composite material consisting of a cylindrical TI fiber of circular cross
% section embedded in a TI matrix. Representative volume element are
% hexagonal cells.
%
% The program has been initially designed to model the effective properties of compact bone at the
% millimeter scale.

% %%%%%%% Inputs and outputs
% The input data are the elastic properties of the matrix and fiber, and
% the volume fraction of fiber.
% input.Cm = tensor in matrix form for the matrix
% input.Cf = tensor in matrix form for the fiber
% input.vf = vector of volume fractions of fiber ranging from 0 to 1
% input.info : info string
%
% Notation convention for tensors in matrix form =
% [C11 C12 C13 0 0 0...
%     C12 C22 C23 0 0 0...
%     C13 C23 C33 0 0 0...
%     0 0 0 C44 0 0...
%     0 0 0 0 C44 0...
%     0 0 0 0 0 C66]; (C44=C55 for TI)
%
% option is a structure
% option.nterms % number of terms (odd) in the multipole expansion (default = 5)
%
% sol.C{:} are the homogenized properties for each input volume fraction.

load('ForceStruc') ; % load useful data - must be in the same directory as main function
global ForceStruc

if (nargin~=2)
    nterms = 5 ;
    disp(['number of terms in the expansion set to ' num2str(nterms) ' (default)'])
else
    nterms = option.nterms ;
    disp(['number of terms in the expansion set to ' num2str(nterms)])
end

la1 =input.Cm(1,2) ; mu1 = input.Cm(6,6) ; lah1=input.Cm(1,3) ; muh1=input.Cm(4,4) ; nu1=input.Cm(3,3) ;
la2 =input.Cf(1,2) ; mu2 = input.Cf(6,6) ; lah2=input.Cf(1,3) ; muh2=input.Cf(4,4) ; nu2=input.Cf(3,3) ;
vf = input.vf ;
for i=1:length(vf)
    
   R = sqrt(vf(i)*(sqrt(3)/2)/pi);
    phi=vf(i) ; p0 = la1/mu1 ; p0h =lah1/mu1 ; p1 = la2/mu1 ;
    p1h = lah2/mu1 ; m0 = mu1/mu1 ; m0h = muh1/mu1 ; m1 = mu2/mu1 ;
    m1h = muh2/mu1 ; ti = (muh1/muh2) ; ka1 = (p1+3*m1)/(p1+m1) ;
    pa = phi*p1+(1-phi)*p0 ; pah = phi*p1h+(1-phi)*p0h ; ma = phi*m1+(1-phi)*m0 ;
    nua = (1-phi)*nu1/mu1 + phi*nu2/mu1 ; P1 = p1-p0 ; P1h = p1h - p0h ;
    M1 = m1-m0 ; M1h = m1h - m0h ; D = 1 ;
    
    %%
    forceterm = 11 ;
    [sol] = fevalAS_HEXA (la1,la2,mu1,mu2,lah1, lah2,muh1, muh2,R,forceterm,nterms) ;
    are1 = sol(1) ;  are3 = sol(2) ;
    switch nterms
        case 3, bre1 = sol(3);
        case 5, bre1 = sol(4);
        case 7, bre1 = sol(5);
        case 9, bre1 = sol(6);
        case 11, bre1 = sol(7);
    end
    
    clear sol
    H1111 = (phi/(2*m1))*(...
        (ka1-1)*are1 - bre1 - (3*phi*D)/pi*are3 );
    H2211 = (phi/(2*m1))*(...
        (ka1-1)*are1 + bre1 + (3*phi*D)/pi*are3 );
    clear are1 bre1  are3
    %%
    forceterm = 33 ;
    [sol] = fevalAS_HEXA (la1,la2,mu1,mu2,lah1, lah2,muh1, muh2,R,forceterm,nterms) ;
    are1 = sol(1) ; are3 = sol(2) ;
    switch nterms
        case 3, bre1 = sol(3);
        case 5, bre1 = sol(4);
        case 7, bre1 = sol(5);
        case 9, bre1 = sol(6);
        case 11, bre1 = sol(7);
    end
    clear sol
    H1133 = (phi/(2*m1))*(...
        (ka1-1)*are1 - bre1 - (3*phi*D)/pi*are3 );
    H2233 = (phi/(2*m1))*(...
        (ka1-1)*are1 + bre1 + (3*phi*D)/pi*are3 );
    clear are1 bre1  are3
    %%
    forceterm = 44 ;
    [sol] = fevalAS_HEXA (la1,la2,mu1,mu2,lah1, lah2,muh1, muh2,R,forceterm,nterms) ;
    switch nterms
        case 3, SetEndp = 2;
        case 5, SetEndp = 3;
        case 7, SetEndp = 4;
        case 9, SetEndp = 5;
        case 11, SetEndp = 6;
    end
    
    for np = 1:SetEndp ;
        npIndex = [1 3 5 7 9 11] ;
        gam(npIndex(np)) = sol(np) ;
    end
    
    clear sol
    %%
    S11 = P1*(H1111+H2211) ;
    S11h = P1h*(H1111+H2211) ;
    S33h = P1h*(H1133+H2233) ;
    T1111 = M1*H1111 ;
    T2211 = M1*H2211 ;
    switch nterms
        case 3, beta = -3.6276 * gam(1) ;
        case 5, beta = -3.6276 * gam(1) - 29.3152 * gam(5) ;
        case 7, beta = -3.6276 * gam(1) - 29.3152 * gam(5) - 192.886 * gam(7) ;
        case 9, beta = -3.6276 * gam(1) - 29.3152 * gam(5) - 192.886 * gam(7) - 1332.6 * gam(9) ;
        case 11, beta = -3.6276 * gam(1) - 29.3152 * gam(5) - 192.886 * gam(7) - 1332.6 * gam(9) - 9848.24 * gam(11) ;
    end
    
    alpha = 2*ti * beta/(ti+1)+ (ti-1)/(ti+1)  ;
    %
    C11 = pa + 2*ma + S11 + 2*T1111 ;
    C33 = nua + S33h ;
    C44 =(muh1/mu1) * ( ti * (1-phi) + phi + phi * (1-ti)*alpha ) /ti ;
    C12 = pa + S11 + 2*T2211 ;
    C13 = pah + S11h ;
    C23 = C13 ; C22 = C11 ; C55 = C44 ; C66 = .5*(C11-C12) ;
    
    C = [C11 C12 C13 0 0 0;...
        C12 C22 C23 0 0 0;...
        C13 C23 C33 0 0 0;...
        0 0 0 C44 0 0;...
        0 0 0 0 C55 0;...
        0 0 0 0 0 C66] ; % C44 = C55 (TI)
    %
    output.C{i}=mu1*C; clear C
end
end

%%
function [sol]=  fevalAS_HEXA (la1,la2,mu1,mu2,lah1, lah2,muh1, muh2,R,forceterm,nterms) ;
global ForceStruc

switch forceterm
    case 11
        l1 = ForceStruc.n{nterms}.l111 ;
        l2 = ForceStruc.n{nterms}.l112 ;
    case 33
        l1 = ForceStruc.n{nterms}.l331 ;
        l2 = ForceStruc.n{nterms}.l332 ;
    case 44
        l1 = ForceStruc.n{nterms}.l441 ;
        l2 = ForceStruc.n{nterms}.l442 ;
end

nlignes = size(eval(l1),2) ;
b= -cell2mat(eval(l1)); % force vector
evl2 = eval(l2) ; % construction of the matrix
for ii=1:nlignes
    tps2 = cell2mat(evl2{ii});
    A (ii,:)= tps2; clear tps2
end
%if rcond(A) < 1e-3; A, pause ; end
sol = A\b' ; %
% sol = inv(A)*b' ;


end % eofunction
